import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_codebuild._jsii
import aws_cdk.aws_codepipeline._jsii
import aws_cdk.aws_codepipeline_actions._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sns_subscriptions._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-codepipeline-slack",
    "1.0.83",
    __name__[0:-6],
    "cdk-codepipeline-slack@1.0.83.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
